@@ -17,11 +17,7 @@ void pattNoteUp(bool sampleAllFlag);
 void pattNoteDown(bool sampleAllFlag);
 void pattOctaUp(bool sampleAllFlag);
 void pattOctaDown(bool sampleAllFlag);
-void exitGetTextLine(bool updateValue);
-void getTextLine(int16_t editObject);
-void getNumLine(uint8_t type, int16_t editObject);
 void handleEditKeys(SDL_Scancode scancode, bool normalMode);
 bool handleSpecialKeys(SDL_Scancode scancode);
 int8_t keyToNote(SDL_Scancode scancode);
-void updateTextObject(int16_t editObject);
 void handleSampleJamming(SDL_Scancode scancode);
